<?php
/**
 * Extended Contact
 *
 * @author emanuele
 * @license   BSD http://opensource.org/licenses/BSD-3-Clause
 *
 * @version 0.0.1
 */

class Contact_Controller extends Action_Controller
{
	/**
	 * Intended entry point for this class.
	 * By default, this is called for action=register
	 *
	 * @see Action_Controller::action_index()
	 */
	public function action_index()
	{
		// figure out what action to do... register, what else.
		$this->action_contact();
	}

	protected function _canAccess()
	{
		global $user_info, $modSettings;
		
		// Already inside, no need to use this, just send a PM
		// Disabled, you cannot enter.
		return !$user_info['is_guest'] || empty($modSettings['enable_contactform']) || $modSettings['enable_contactform'] == 'disabled';
	}

	protected function _sendMsg()
	{
		global $context, $txt;

		checkSession('post');
		validateToken('contact');
		spamProtection('contact');

		// No errors, yet.
		$context['errors'] = array();
		loadLanguage('Errors');

		// Could they get the right send topic verification code?
		require_once(SUBSDIR . '/VerificationControls.class.php');
		require_once(SUBSDIR . '/Members.subs.php');

		// form validation
		require_once(SUBSDIR . '/DataValidator.class.php');
		$validator = new Data_Validator();
		$validator->sanitation_rules(array(
			'emailaddress' => 'trim',
			'contactmessage' => 'trim|Util::htmlspecialchars'
		));
		$validator->validation_rules(array(
			'emailaddress' => 'required|valid_email',
			'contactmessage' => 'required'
		));
		$validator->text_replacements(array(
			'emailaddress' => $txt['error_email'],
			'contactmessage' => $txt['error_message']
		));

		// Any form errors
		if (!$validator->validate($_POST))
			$context['errors'] = $validator->validation_errors();

		if ($this->_needsVerification())
		{
			// How about any verification errors
			$verificationOptions = array(
				'id' => 'contactform',
			);
			$context['require_verification'] = create_control_verification($verificationOptions, true);

			if (is_array($context['require_verification']))
			{
				foreach ($context['require_verification'] as $error)
					$context['errors'][] = $txt['error_' . $error];
			}
		}

		// No errors, then send the PM to the admins
		if (empty($context['errors']))
		{
			$admins = admins();
			if (!empty($admins))
			{
				require_once(SUBSDIR . '/PersonalMessage.subs.php');
				sendpm(array('to' => array_keys($admins), 'bcc' => array()), $txt['contact_subject'], $_REQUEST['contactmessage'], false, array('id' => 0, 'name' => $validator->emailaddress, 'username' => $validator->emailaddress));
			}

			// Send the PM
			return true;
		}
		else
		{
			$context['emailaddress'] = $validator->emailaddress;
			$context['contactmessage'] = $validator->contactmessage;
		}
	}

	protected function _needsVerification()
	{
		global $user_info;

		return $user_info['is_guest'];
	}

	public function action_contact()
	{
		global $context, $txt, $modSettings;

		if (!$this->_canAccess())
			redirectexit();

		loadLanguage('Login');
		loadLanguage('ExtendedContact');
		loadTemplate('Register');
		loadCSSFile('ExtendedContact.css');

		if (isset($_REQUEST['send']))
			$completed = $this->_sendMsg();
		else
			$completed = false;

		if ($completed)
			$context['sub_template'] = 'contact_form_done';
		else
		{
			$context['sub_template'] = 'contact_form';
			$context['page_title'] = $txt['admin_contact_form'];

			if ($this->_needsVerification())
			{
				require_once(SUBSDIR . '/VerificationControls.class.php');
				$verificationOptions = array(
					'id' => 'contactform',
				);
				$context['require_verification'] = create_control_verification($verificationOptions);
				$context['visual_verification_id'] = $verificationOptions['id'];
			}
			else
				$context['require_verification'] = false;

			if (!empty($modSettings['contactform_text']))
			{
				require_once(EXTDIR . '/markdown/markdown.php');
				$context['contactform_text'] = Markdown($modSettings['contactform_text']);

				loadTemplate('ExtendedContact');
				Template_Layers::getInstance()->addEnd('contactform_text');
			}
		}

		createToken('contact');
	}
}